@@ -15,8 +15,9 @@ def get_from_graph_api(graphAPI, query):
                 raise
 
 
-def get_application_graph():
-    token = facepy.utils.get_application_access_token(
-            settings.FACEBOOK_APP_ID, settings.FACEBOOK_APP_SECRET,
-            api_version='2.1')
+def get_application_graph(version):
+    token = (facepy.utils
+             .get_application_access_token(settings.FACEBOOK_APP_ID,
+                                           settings.FACEBOOK_APP_SECRET,
+                                           api_version=version))
     return graph_api.get_graph(token)
